ANSIBLE_CONNECTION_CHOICES = (
    ('network_cli', 'network_cli'),
    ('paramiko_ssh', 'paramiko'),
    ('chroot', 'chroot'),
    ('docker', 'docker'),
    ('httpapi', 'httpapi'),
    ('netconf', 'netconf'),
    ('winrm', 'winrm')
)

ANSIBLE_NETWORK_OS_CHOICES = (
    ('a10', 'a10'),
    ('aci', 'aci'),
    ('aireos', 'aireos'),
    ('aos', 'aos'),
    ('aruba', 'aruba'),
    ('asa', 'asa'),
    ('f5', 'f5'),
    ('ios', 'ios'),
    ('iosxr', 'iosxr'),
    ('nxos', 'nxos')

)
